@@ -10,15 +10,14 @@
 #include <osmium/memory/buffer.hpp>
 
 TEST_CASE("Writer") {
-
     osmium::io::Header header;
     header.set("generator", "test_writer.cpp");
 
-    osmium::io::Reader reader(with_data_dir("t/io/data.osm"));
+    osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
     osmium::memory::Buffer buffer = reader.read();
     REQUIRE(buffer);
     REQUIRE(buffer.committed() > 0);
-    auto num = std::distance(buffer.select<osmium::OSMObject>().cbegin(), buffer.select<osmium::OSMObject>().cend());
+    const auto num = std::distance(buffer.select<osmium::OSMObject>().cbegin(), buffer.select<osmium::OSMObject>().cend());
     REQUIRE(num > 0);
     REQUIRE(buffer.select<osmium::OSMObject>().cbegin()->id() == 1);
 
@@ -28,7 +27,7 @@ TEST_CASE("Writer") {
 
         SECTION("Empty buffer") {
             filename = "test-writer-out-empty-buffer.osm";
-            osmium::io::Writer writer(filename, header, osmium::io::overwrite::allow);
+            osmium::io::Writer writer{filename, header, osmium::io::overwrite::allow};
             osmium::memory::Buffer empty_buffer(1024);
             writer(std::move(empty_buffer));
             writer.close();
@@ -36,13 +35,13 @@ TEST_CASE("Writer") {
 
         SECTION("Invalid buffer") {
             filename = "test-writer-out-invalid-buffer.osm";
-            osmium::io::Writer writer(filename, header, osmium::io::overwrite::allow);
+            osmium::io::Writer writer{filename, header, osmium::io::overwrite::allow};
             osmium::memory::Buffer invalid_buffer;
             writer(std::move(invalid_buffer));
             writer.close();
         }
 
-        osmium::io::Reader reader_check(filename);
+        osmium::io::Reader reader_check{filename};
         osmium::memory::Buffer buffer_check = reader_check.read();
         REQUIRE(!buffer_check);
     }
@@ -51,7 +50,7 @@ TEST_CASE("Writer") {
 
         SECTION("Writer buffer") {
             filename = "test-writer-out-buffer.osm";
-            osmium::io::Writer writer(filename, header, osmium::io::overwrite::allow);
+            osmium::io::Writer writer{filename, header, osmium::io::overwrite::allow};
             writer(std::move(buffer));
             writer.close();
 
@@ -62,7 +61,7 @@ TEST_CASE("Writer") {
 
         SECTION("Writer item") {
             filename = "test-writer-out-item.osm";
-            osmium::io::Writer writer(filename, header, osmium::io::overwrite::allow);
+            osmium::io::Writer writer{filename, header, osmium::io::overwrite::allow};
             for (const auto& item : buffer) {
                 writer(item);
             }
@@ -71,13 +70,13 @@ TEST_CASE("Writer") {
 
         SECTION("Writer output iterator") {
             filename = "test-writer-out-iterator.osm";
-            osmium::io::Writer writer(filename, header, osmium::io::overwrite::allow);
+            osmium::io::Writer writer{filename, header, osmium::io::overwrite::allow};
             auto it = osmium::io::make_output_iterator(writer);
             std::copy(buffer.cbegin(), buffer.cend(), it);
             writer.close();
         }
 
-        osmium::io::Reader reader_check(filename);
+        osmium::io::Reader reader_check{filename};
         osmium::memory::Buffer buffer_check = reader_check.read();
         REQUIRE(buffer_check);
         REQUIRE(buffer_check.committed() > 0);
@@ -89,7 +88,7 @@ TEST_CASE("Writer") {
         int error = 0;
         try {
             filename = "test-writer-out-fail1.osm";
-            osmium::io::Writer writer(filename, header, osmium::io::overwrite::allow);
+            osmium::io::Writer writer{filename, header, osmium::io::overwrite::allow};
             throw 1;
         } catch (int e) {
             error = e;
@@ -102,7 +101,7 @@ TEST_CASE("Writer") {
         int error = 0;
         try {
             filename = "test-writer-out-fail2.osm";
-            osmium::io::Writer writer(filename, header, osmium::io::overwrite::allow);
+            osmium::io::Writer writer{filename, header, osmium::io::overwrite::allow};
             writer(std::move(buffer));
             throw 2;
         } catch (int e) {
@@ -114,4 +113,3 @@ TEST_CASE("Writer") {
 
 }
 
-
